<?php

namespace App\Providers;

use App\Repositories\CommunityRepository;
use App\Repositories\JobExperienceRepository;
use App\Repositories\RateMyPayRepository;
use Illuminate\Support\ServiceProvider;

class RepositoryServiceProvider extends ServiceProvider
{
    public function register(): void
    {
        $this->app->bind(
            JobExperienceRepository::class
        );
        $this->app->bind(
            RateMyPayRepository::class
        );
        $this->app->bind(
            CommunityRepository::class
        );
    }

    public function boot(): void {}
}
